@@ -13,7 +13,7 @@ def docgraph():
             return False
     return True
 
-@hghave.check("flake8", "Flake8 python linter")
+@hghave.check("flake8-mod", "Flake8 linter as a Python module")
 def has_flake8():
     try:
         import flake8
@@ -24,6 +24,17 @@ def has_flake8():
     else:
         return True
 
+@hghave.check("pyflakes-mod", "Pyflakes linter as a Python module")
+def has_pyflakes_mod():
+    try:
+        import pyflakes
+
+        pyflakes.__version__
+    except ImportError:
+        return False
+    else:
+        return True
+
 @hghave.check("check-manifest", "check-manifest MANIFEST.in checking tool")
 def has_check_manifest():
     return hghave.matchoutput('check-manifest --version 2>&1',
@@ -37,8 +48,22 @@ def has_twine():
 @hghave.check("default-cg3", "changegroup3 by default")
 def has_default_changegroup3():
     from mercurial import configitems
+    # experimental.changegroup3 existed for a long time (before our minimum
+    # supported version), first False by default, then True by default, then it
+    # was removed
+
+    # default=False hg <= 6.4 (2cf264e9aa75)
+    # default=True hg <= 7.1 (02cd625b4a78)
 
     try:
         return configitems.coreitems[b'experimental'][b'changegroup3'].default
-    except (AttributeError, KeyError):
+    except KeyError:
+        return True
+
+@hghave.check("delta-compression", "Delta compression")
+def has_delta_compression():
+    try:
+        from mercurial.util import compression
+        return getattr(compression.compressormanager, 'supported_wire_delta_compression', None) is not None
+    except (AttributeError, ImportError):
         return False
